translate.lang.factory

Package translate :: Package lang :: Module factory |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.factory

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007-2010 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """This module provides a factory to instantiate language classes."""
    23
    24  from translate.lang import common
    25  from translate.lang import data
    26
    27  prefix = "code_"
    28
    29
    30 -def getlanguage(code):
    31      """This returns a language class.
    32
    33      @param code: The ISO 639 language code
    34      """
    35      if code:
    36          code = code.replace("-", "_").replace("@", "_").lower()
    37      try:
    38          if code is None:
    39              raise ImportError("Can't determine language code")
    40          if code in ('or', 'is'):
    41              internal_code = prefix + code
    42          else:
    43              internal_code = code
    44          module = __import__("translate.lang.%s" % internal_code, globals(), {}, internal_code)
    45          langclass = getattr(module, internal_code)
    46          return langclass(code)
    47      except ImportError, e:
    48          simplercode = data.simplercode(code)
    49          if simplercode:
    50              relatedlanguage = getlanguage(simplercode)
    51              if isinstance(relatedlanguage, common.Common):
    52                  relatedlanguage = relatedlanguage.__class__(code)
    53              return relatedlanguage
    54          else:
    55              return common.Common(code)
    56